@@ -1,19 +1,15 @@
-#' @title Retrieve tidy dataframe if it exists.
+#' @title Retrieve tidy dataframe if it exists
 #' @name tidy
 #'
 #' @description
 #'
-#' Checks if a `tidy` method exits for a given object, either in `broom` or in
-#' `broom.mixed`. If it does, it turn an object into a tidy tibble, if not,
+#' Checks if a `tidy` method exits for a given object, either in `{broom}` or in
+#' `{broom.mixed}`. If it does, it turn an object into a tidy tibble, if not,
 #' return a `NULL`. In this case, you can try the
 #' [broomExtra::tidy_parameters()] function.
 #'
 #' @inheritParams generics::tidy
 #'
-#' @importFrom rlang is_null
-#' @importFrom broom tidy
-#' @importFrom broom.mixed tidy
-#'
 #' @inherit generics::tidy return value
 #'
 #' @seealso \code{\link{grouped_tidy}}, \code{\link{tidy_parameters}}
@@ -25,11 +21,11 @@
 #' @export
 
 tidy <- function(x, ...) {
-  # check if `broom` has a tidy method for a given object
+  # check if `{broom}` has a tidy method for a given object
   f <- tryCatch(broom::tidy(x, ...), error = function(e) NULL)
 
-  # if not, check if `broom.mixed` has a tidy method for a given object
-  if (rlang::is_null(f)) f <- tryCatch(broom.mixed::tidy(x, ...), error = function(e) NULL)
+  # if not, check if `{broom.mixed}` has a tidy method for a given object
+  if (is_null(f)) f <- tryCatch(broom.mixed::tidy(x, ...), error = function(e) NULL)
 
   # return the tidy
   return(f)
@@ -41,16 +37,13 @@ tidy <- function(x, ...) {
 #'
 #' @description
 #'
-#' Checks if a `glance` method exits for a given object, either in `broom` or in
-#' `broom.mixed`. If it does, return the model summary dataframe, if not, return
+#' Checks if a `glance` method exits for a given object, either in `{broom}` or in
+#' `{broom.mixed}`. If it does, return the model summary dataframe, if not, return
 #' a `NULL`. In this case, you can try the [broomExtra::glance_performance()]
 #' function.
 #'
 #' @inheritParams generics::glance
 #'
-#' @importFrom broom glance
-#' @importFrom broom.mixed glance
-#'
 #' @inherit generics::glance return value
 #'
 #' @seealso \code{\link{grouped_glance}}, \code{\link{glance_performance}}
@@ -62,11 +55,11 @@ tidy <- function(x, ...) {
 #' @export
 
 glance <- function(x, ...) {
-  # check if `broom` has a glance method for a given object
+  # check if `{broom}` has a glance method for a given object
   f <- tryCatch(broom::glance(x, ...), error = function(e) NULL)
 
-  # if not, check if `broom.mixed` has a glance method for a given object
-  if (rlang::is_null(f)) f <- tryCatch(broom.mixed::glance(x, ...), error = function(e) NULL)
+  # if not, check if `{broom.mixed}` has a glance method for a given object
+  if (is_null(f)) f <- tryCatch(broom.mixed::glance(x, ...), error = function(e) NULL)
 
   # return the glance
   return(f)
@@ -76,15 +69,12 @@ glance <- function(x, ...) {
 #' @name augment
 #' @description
 #'
-#' Checks if a `augment` method exits for a given object, either in `broom` or
-#' in `broom.mixed`. If it does, return the model summary dataframe, if not,
+#' Checks if a `augment` method exits for a given object, either in `{broom}` or
+#' in `{broom.mixed}`. If it does, return the model summary dataframe, if not,
 #' return a `NULL`.
 #'
 #' @inheritParams generics::augment
 #'
-#' @importFrom broom augment
-#' @importFrom broom.mixed augment
-#'
 #' @inherit generics::augment return value
 #'
 #' @seealso \code{\link{grouped_augment}}
@@ -96,11 +86,11 @@ glance <- function(x, ...) {
 #' @export
 
 augment <- function(x, ...) {
-  # check if `broom` has a augment method for a given object
+  # check if `{broom}` has a augment method for a given object
   f <- tryCatch(broom::augment(x, ...), error = function(e) NULL)
 
-  # if not, check if `broom.mixed` has a augment method for a given object
-  if (rlang::is_null(f)) f <- tryCatch(broom.mixed::augment(x, ...), error = function(e) NULL)
+  # if not, check if `{broom.mixed}` has a augment method for a given object
+  if (is_null(f)) f <- tryCatch(broom.mixed::augment(x, ...), error = function(e) NULL)
 
   # return the augment
   return(f)
